@@ -53,7 +53,9 @@ def parser_args():
     parser.add_argument('--leak-check', action="store_true", help="默认False，填写参数代表为true，用于筛选漏检出数据。是为True，否为False")
     parser.add_argument('--error-check', action="store_true", help="默认False，填写参数代表为true，用于筛选误检出数据。是为True，否为False")
     parser.add_argument('--right-check', action="store_true", help="默认False，填写参数代表为true，用于筛选正确检出数据。是为True，否为False")
-    parser.add_argument('--is-PCA', action="store_true", help="默认False，填写参数代表为true，用于直方图降维条件判断。是为True，但会造成信息丢失，否为False，信息更准确")
+    parser.add_argument('--background', action="store_true", help="默认False，填写参数代表为true，用于把系统输出的json转换为labelme对应的json。是为True，否为False")
+    parser.add_argument('--is-PCA', action="store_true",
+                        help="默认False，填写参数代表为true，用于直方图降维条件判断。是为True，但会造成信息丢失，否为False，信息更准确")
     parser.add_argument('--delete', action="store_true", help="默认False，填写参数代表为true，用于删除勾选数据。是为True，否为False")
     parser.add_argument('--opt', type=str, help="opt值为local表示局部直方图计算，opt值为global表示全局直方图计算")
     parser.add_argument('--json-file', type=str, help="图像文件约定目录规则,00.images")
@@ -131,6 +133,14 @@ def parser_args():
         return args
     elif args.function == 'md5':  # 对每张图像的标注文件赋值MD5
         return args
+    elif args.function == 'video_mark_convert_labelme':  #
+        return args
+    elif args.function == 'change':  # 把系统输出格式，转换为labelme标注工具可读格式。
+        return args
+    elif args.function == 'rename_file_name':  # 把中文文件名称，重命名为英文
+        return args
+    elif args.function == 'soft_deletion':  # 把json数据删除，属于软删除，等同于只拷贝一份图像，原始数据保留
+        return args
     else:
         assert not args.function, '传入的操作功能参数不对:{}'.format(args.function)
 
@@ -138,7 +148,7 @@ def parser_args():
 def main():
     # async def main():
     args = parser_args()
-    print(args)
+    # print(args)
     # 把字符串转换成，列表内存储字典元素
     input_datasets_list = ast.literal_eval(args.input_datasets.replace('\\', '/'))
     if args.sync:  # 同步读写数据处理
@@ -151,6 +161,8 @@ def main():
             print(time.time() - async_time)
         if args.function == 'pinyin':
             data_info.hanzi_to_pinyin()  # 对中文路径转拼音后，重新输出
+        # if args.function == 'rename':  # 对中文的文件名称，转英文
+        #     data_info.get_english_name()
     else:  # 异步读写数据处理，存在少部分同步写数据处理
         async_time = time.time()
         data_info = LabelmeLoad(args, input_datasets_list)  # 初始化输入参数
@@ -162,7 +174,7 @@ def main():
         if args.function == 'merge':  # 合并功能
             if args.rectangle_merge:  # 删除人工标注矩形框，然后与模型预测出来的矩形框进行合并功能
                 # 加载模型预测的labelme数据集
-                model_dataset_info = asyncio.run(data_info.recursive_walk(input_datasets_list[0].get('model_input_dir')))
+                model_dataset_info = asyncio.run(data_info.recursive_walk(input_datasets_list[0].get('model_input_dir'), args.function))
                 # 先删除人工标注的矩形框
                 # original_dataset_info = dataset.del_label(args.del_label)
                 dataset.labelme_rectangle_merge(args, model_dataset_info)
@@ -185,6 +197,12 @@ def main():
             elif args.output_format == 'voc':  # voc转labelme
                 voc = BaseVoc(dataset_info, input_datasets_list[0].get('input_xml_dir'))
                 voc.voc2labelme()
+            elif args.output_format == 'txt':  # 视频标注转labelme，txt转labelme
+                txt = BaseTxt(dataset_info, input_datasets_list[0].get('input_txt_dir'))
+                txt.txt2labelme()
+            elif args.output_format == 'sys':  # 把系统输出格式，转换为labelme标注工具可读格式。
+                sys = BaseSys(dataset_info, args)
+                sys.sys2labelme()
         elif args.function == 'rename':  # 重命名label标签功能
             dataset.rename_labelme(args)
             # dataset.save_labelme(args.output_dir, None, None)
@@ -240,12 +258,12 @@ def main():
         # 准确率 Accuracy = (TP + TN) / (TP + FN + FP + TN)，（70 + 26） / （70 + 8 + 26 + 0）
         elif args.function == 'IOU':  # 把模型预测结果与人工标注结果进行对比，计算模型预测结果的漏检、误检、检出
             # 加载模型预测的labelme数据集
-            model_dataset_info = asyncio.run(data_info.recursive_walk(input_datasets_list[0].get('model_input_dir')))
+            model_dataset_info = asyncio.run(data_info.recursive_walk(input_datasets_list[0].get('model_input_dir'), args))
             # 加载标注数据集
             dataset.model_to_iou(model_dataset_info, args)
         elif args.function == 'compare':  # 数据集比较功能，目前比较漏检和正确检出图像相同的情况
             # 加载正确检出数据集
-            right_check_dataset_info = asyncio.run(data_info.recursive_walk(input_datasets_list[0].get('model_input_dir')))
+            right_check_dataset_info = asyncio.run(data_info.recursive_walk(input_datasets_list[0].get('model_input_dir'), args))
             # 加载漏检出数据集
             dataset.compare_labelme(right_check_dataset_info, args)
         elif args.function == 'mosaic':
@@ -256,6 +274,10 @@ def main():
             dataset.chipea_make_flags(args)
         elif args.function == 'md5':
             dataset.chipea_make_md5(args)
+        elif args.function == 'soft_deletion':  # 软删除json
+            dataset.soft_deletion_json(args)
+        elif args.function == 'rename_file_name':  # 自定义格式把文件重命名
+            dataset.rename_file_name(args)
 
 
 if __name__ == '__main__':
