@@ -10,13 +10,14 @@ import hashlib
 import json
 from tqdm import tqdm
 from PIL import Image
-from typing import List, Optional
+from typing import List, Optional, Union
 import aiofiles
 from concurrent.futures import ThreadPoolExecutor
 from tqdm.asyncio import tqdm_asyncio  # 引入 tqdm 的异步版本
 import shutil
 from pypinyin import pinyin, Style
 import zipfile
+# from googletrans import Translator
 
 
 class LabelmeLoad(object):
@@ -26,7 +27,6 @@ class LabelmeLoad(object):
 
     def __init__(self, *args, **kwargs):
         self.parameter = args[0]
-        print(self.parameter)
         self.type_args = args[1]
         self.group_error_path = ''
         self.out_of_bounds_path = ''
@@ -122,15 +122,14 @@ class LabelmeLoad(object):
             data_path['background'] = False
         return data_path
 
-    async def process_file(self, file_path: str, root_dir: str) -> dict:
+    async def process_file(self, file_path: str, root_dir: str) -> Union[dict, str]:  # 返回两种类型之一，要么是一个字典（dict），要么是一个字符串（str）。
         """
         异步处理文件，返回封装后的数据结构
         """
         obj_path = Path(file_path)
-        print(self)
-        print(self.parameter.output_dir)
         if obj_path.suffix in self.parameter.file_formats:
-            if file_path.count('00.images') == 1 or self.parameter.output_format == 'voc':  # 设计规则，根据图片文件查找json文件，同时根据约定的目录规则封装labelme数据集
+            # 设计规则，根据图片文件查找json文件，同时根据约定的目录规则封装labelme数据集
+            if file_path.count('00.images') == 1 or self.parameter.output_format == 'voc' or self.parameter.output_format == 'sys':
                 relative_path = os.path.join('..', obj_path.parent.name, obj_path.name)
                 image_dir = str(obj_path.parent).replace('\\', '/').replace(root_dir, '').strip('\\/')
                 labelme_dir = os.path.join(image_dir.replace('00.images', '').strip('\\/'), '01.labelme')
@@ -140,7 +139,7 @@ class LabelmeLoad(object):
                     # 打印的时候不需要用到，非打印功能，都会用到
                     json_path = os.path.join(self.parameter.output_dir, labelme_dir, labelme_file)
                 original_json_path = os.path.join(root_dir, labelme_dir, labelme_file)
-                md5_value = await self.calculate_file_md5_async(file_path)
+                md5_value = await self.calculate_file_md5_async(file_path)  # 如果不是图像，这里获取MD5值是无法获取的，会直接跳转，存在未知图像后缀格式数据的逻辑
                 if self.parameter.output_dir:  # 如果有输出路径，则自定义错误输出目录
                     self.group_error_path = os.path.join(self.parameter.output_dir, 'group_error_path')
                     self.out_of_bounds_path = os.path.join(self.parameter.output_dir, 'out_of_bounds_path')
@@ -173,6 +172,9 @@ class LabelmeLoad(object):
                 labelme_info = await self.load_labelme(data_path)  # 异步加载json文件
                 return labelme_info
             else:
+                # if self.parameter.function == 'change':  # 如果功能属于，系统输出结果，转labelme可用格式，直接追加图像路径，通过图像路径找到json路径，读取内容，转换格式
+                #     return file_path
+                # else:
                 print(f'文件夹目录不符合约定标准，请检查{file_path}')
         else:
             print(f'存在未知图像后缀格式数据{file_path}')
@@ -183,12 +185,14 @@ class LabelmeLoad(object):
         """
         all_images_file_path = []
         file_paths = await self.read_directory(root_dir)  # 异步读取文件路径
+        print("异步读取文件路径完成")
         # tasks = [self.process_file(file_path, root_dir) for file_path in file_paths]  # 列表推导式处理文件异步任务列表，与下面的三行代码区别不大
         if args == "create_dir":
             return file_paths
         else:
             tasks = list()
-            for file_path in file_paths:
+            print("异步封装数据开始")
+            for file_path in tqdm(file_paths):
                 # 使用 ensure_future() 函数能够确保协程一定被封装成任务对象，即使协程返回的是普通值而不是协程对象，该值也会被封装为一个 Future 对象，成为可调度的任务。
                 tasks.append(asyncio.ensure_future(self.process_file(file_path, root_dir)))
             # 使用 asyncio.gather() 函数同时运行多个异步任务
@@ -313,3 +317,33 @@ class LabelmeLoad(object):
                     # 如果文件在文件列表中，则返回真继续往下执行
                     file_path_name.append(os.path.join(root, file))
         return file_path_name
+
+    @staticmethod
+    def get_txt_path(root_dir):
+        file_path_name = list()  # 文件路径
+        for root, dirs, files in os.walk(root_dir, topdown=True):
+            dirs.sort()
+            files.sort()
+            # 遍历文件名称列表
+            for file in files:
+                txt_dict = dict()  # 定义字典，存储key为关键判断值，value为路径
+                obj_path = Path(file)
+                key = obj_path.stem.split("_")[0]
+                value = os.path.join(root, file)
+                txt_dict[key] = value
+                # 如果读取的文件后缀，在指定的后缀列表中，则返回真继续往下执行
+                file_path_name.append(txt_dict)
+        return file_path_name
+
+    def get_english_name(self):
+        file_name = list()
+        for root, dirs, files in tqdm(os.walk(self.type_args[0].get('input_dir'), topdown=True)):
+            for file in files:
+                path_name = os.path.join(root, file).replace('\\', '/')
+                obj_path = Path(file)  # 初始化路径对象为对象
+                if obj_path.suffix in self.parameter.file_formats:
+                    # 所有labelme数据集存放规则为：图像必须存放在00.images目录中，图像对应的json文件必须存放在01.labelme中
+                    if root.count('00.images') == 1:  # 设计规则，根据00.images目录，做唯一判断
+                        if path_name not in file_name:
+                            file_name.append(path_name)
+        print(file_name)
